@@ -3,8 +3,8 @@
 from ._ascii import ASCIIRenderer
 from ._base import dfs, dfs_filter, PayloadMerger
 from ._evaluation import Evaluator
-from ._einspec import EinsteinSpecGenerator
-from ._compile import Compiler
+from ._einop_compiler import EinopCompiler
+from ._type_deduction import TypeDeducer
 from ._indexness import IndexnessAnalyzer
 from ._initialization import LeafInitializer
 from ._latex import LatexRenderer
@@ -17,9 +17,9 @@ __all__ = [
     'dfs',
     'dfs_filter',
     'ASCIIRenderer',
-    'Compiler',
+    'TypeDeducer',
     'Evaluator',
-    'EinsteinSpecGenerator',
+    'EinopCompiler',
     'IndexnessAnalyzer',
     'LeafInitializer',
     'LatexRenderer',
