@@ -11,7 +11,7 @@ class SlicingPropagator(TranscribeInterpreter):
     and intermediate nodes should be computed to get the desired
     output at the root.'''
 
-    _traversal_order = TranscribeInterpreter.TraversalOrder.PRE
+    _traversal_order = TranscribeInterpreter.TraversalOrder.BREADTH
 
     def __init__(self, slices):
         self.slices = slices
@@ -80,15 +80,13 @@ class SlicingPropagator(TranscribeInterpreter):
                 rhs_slices.append(slice_dict[i])
             except KeyError:
                 rhs_slices.append(slice(None))
-        lhs.slices = lhs_slices
-        rhs.slices = rhs_slices
-        if outidx is not None:
-            outidx.slices = None
+        lhs.slices = tuple(lhs_slices)
+        rhs.slices = tuple(rhs_slices)
 
     def tran(self, src: P.Numeric, indices: P.indices, slices, **kwargs):
-        src.slices = [
+        src.slices = tuple([
             slices[src.live_indices.index(i)] for i in indices.live_indices
-        ]
+        ])
 
     def abstract_dest(self, src: P.Numeric, indices: P.indices, **kwargs):
         raise NotImplementedError()
